==> cxf-services-xkms-common-3.5.8-sources.jar: org/apache/cxf/xkms/model/xkms/RevokeRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RevokeRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RevokeRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeKeyBinding"/&gt;
 *         &lt;choice&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCode"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RevokeRequestType", propOrder = {
    "revokeKeyBinding",
    "authentication",
    "revocationCode"
})
public class RevokeRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RevokeKeyBinding", required = true)
    protected KeyBindingType revokeKeyBinding = new KeyBindingType();
    @XmlElement(name = "Authentication")
    protected AuthenticationType authentication = new AuthenticationType();
    @XmlElement(name = "RevocationCode")
    protected byte[] revocationCode;

    /**
     * Gets the value of the revokeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRevokeKeyBinding() {
        return revokeKeyBinding;
    }

    /**
     * Sets the value of the revokeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRevokeKeyBinding(KeyBindingType value) {
        this.revokeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the revocationCode property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCode() {
        return revocationCode;
    }

    /**
     * Sets the value of the revocationCode property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCode(byte[] value) {
        this.revocationCode = value;
    }

}

==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/RevokeRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RevokeRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RevokeRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeKeyBinding"/&gt;
 *         &lt;choice&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCode"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RevokeRequestType", propOrder = {
    "revokeKeyBinding",
    "authentication",
    "revocationCode"
})
public class RevokeRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RevokeKeyBinding", required = true)
    protected KeyBindingType revokeKeyBinding = new KeyBindingType();
    @XmlElement(name = "Authentication")
    protected AuthenticationType authentication = new AuthenticationType();
    @XmlElement(name = "RevocationCode")
    protected byte[] revocationCode;

    /**
     * Gets the value of the revokeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRevokeKeyBinding() {
        return revokeKeyBinding;
    }

    /**
     * Sets the value of the revokeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRevokeKeyBinding(KeyBindingType value) {
        this.revokeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the revocationCode property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCode() {
        return revocationCode;
    }

    /**
     * Sets the value of the revocationCode property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCode(byte[] value) {
        this.revocationCode = value;
    }

}
